# AUTOGENERATED! DO NOT EDIT! File to edit: nbs/00_model_based_keyword_generation.ipynb (unless otherwise specified).

__all__ = ['BartKeywordGenerator', 'ExtractiveKeywordGenerator', 'AbstractiveKeywordGenerator']

# Cell
from transformers import TextGenerationPipeline, TFAutoModelForPreTraining, TFBartForConditionalGeneration, BartTokenizer, pipeline

# Cell
class BartKeywordGenerator():
  """
  Bart based keyword generator using huggingface transformers
  """
  def __init__(self, model_name, use_cuda=False):
    self.model_name = model_name
    self.model = TFBartForConditionalGeneration.from_pretrained(self.model_name, from_pt=True)
    self.tokenizer = BartTokenizer.from_pretrained(self.model_name)
    self.use_cuda = use_cuda
    self.device = 0 if use_cuda else -1
    self.keyword_generator = pipeline("summarization", model=self.model, tokenizer=self.tokenizer, device=self.device)

  def generate(self, text, max_length=50, **kwargs):

    generated_keywords = self.keyword_generator(text, max_length=max_length, **kwargs)
    keywords = []
    for keyword in generated_keywords:
      keywords.append({"keywords": keyword['summary_text'].split(";")})
    return keywords

  def batch_generate(self, texts, batch_size=8, max_length=50, **kwargs):

    batches = [texts[i:i + batch_size] for i in range(0, len(texts), batch_size)]
    keywords = []

    for batch in batches:
      batch_keywords = self.generate(batch, max_length=max_length, **kwargs)
      keywords.extend(batch_keywords)
    return keywords

# Cell
class ExtractiveKeywordGenerator(BartKeywordGenerator):
  """It will generate extractive keywords using bart based fined tunned model on openkp datasets"""
  def __init__(self, use_cuda=False):
    model_name = "ankur310794/bart-base-keyphrase-generation-openkp"
    super().__init__(model_name, use_cuda)

# Cell
class AbstractiveKeywordGenerator(BartKeywordGenerator):
  """It will generate abstractive keywords using bart based fined tunned model on kpTimes dataset"""
  def __init__(self, use_cuda=False):
    model_name = "ankur310794/bart-base-keyphrase-generation-kpTimes"
    super().__init__(model_name, use_cuda)
